==> ksystemlog-14.11.95.tar.xz: ksystemlog-14.11.95/src/logModePluginsLoader.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _LOG_MODE_PLUGINS_LOADER_H_
#define _LOG_MODE_PLUGINS_LOADER_H_

#include <QObject>

class LogModePluginsLoader: public QObject {
	
	Q_OBJECT
	
	public:
		LogModePluginsLoader(QWidget* parent);
	
		~LogModePluginsLoader();

		void loadPlugins();

	private:
		QWidget* parent;
};

#endif //_LOG_MODE_PLUGINS_LOADER_H_

==> ksystemlog_17.12.3.orig.tar.xz: ksystemlog-17.12.3/src/logModePluginsLoader.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _LOG_MODE_PLUGINS_LOADER_H_
#define _LOG_MODE_PLUGINS_LOADER_H_

#include <QObject>

class LogModePluginsLoader : public QObject
{
    Q_OBJECT

public:
    LogModePluginsLoader(QWidget *parent);

    ~LogModePluginsLoader();

    void loadPlugins();

private:
    QWidget *parent;
};

#endif //_LOG_MODE_PLUGINS_LOADER_H_
